==> aitemplates-0.1.2.tar.gz: aitemplates-0.1.2/README.md <==
# aitemplates

aitemplates is a Python package designed to simplify and streamline your work with the OpenAI API. It provides Python typing support, error checking, and a usage meter to help manage API costs. Additionally, aitemplates offers built-in examples of using ChromaDB and tools for efficient prompt engineering with OpenAI.

## Features

- **Python Typing Support**: Enjoy the benefits of Python's dynamic typing system while using OpenAI API.
- **Error Checking**: Automatically catch and handle errors during API calls.
- **Usage Meter**: Keep track of your OpenAI API usage with a built-in metering system.
- **ChromaDB Integration**: Work directly with ChromaDB from the aitemplates interface.
- **Asynchronous Chat Completions**: Use the `-asnc` flag to run asynchronous chat completions. The built-in `print_every` option prints every time a completion finishes in parallel. If a list is passed into the `response_list` attribute, it updates that list as completions finish. If you'd like to maintain the order of your completions, pass in the `keep_order` boolean as `True`.
- **Prompt Engineering Examples**: Get started quickly with included examples of prompt engineering techniques.

## Installation

You can install aitemplates directly from PyPI:

```bash
pip install aitemplates
```

To get the latest version of the package, you can also clone the repository and install the package by running `pip install -e .` in the repository directory.

## Creating Jupyter Notebook Templates

Create Jupyter notebook templates for prompt engineering with the following command:

```bash
aitemplates name_of_notebook
```

Include a Chroma database in the template with the `-db` flag:

```bash
aitemplates name_of_notebook -db
```

For asynchronous chat completions, add the `-asnc` flag:

```bash
aitemplates name_of_notebook -db -asnc
```

## Documentation

The package includes example notebooks, which provide comprehensive guides and demonstrations of the functionalities provided by aitemplates. To access these notebooks, clone the repository and navigate to the `/notebooks` directory.

Here are the available notebooks:

- `oai_examples.ipynb`: Provides examples for the OpenAI API.
- `chroma_examples.ipynb`: Demonstrates usage of ChromaDB.
- `prompt_engineering_example.ipynb`: A comprehensive guide on prompt engineering, including various techniques, usage of ChromaDB and the OpenAI library together.

## Requirements

- Be sure to have a `.env` file with the `OPENAI_API_KEY` defined in the root of your project. AWS env variables are for ChromaDB deployment https://docs.trychroma.com/deployment
- This library doesn't currently support the use of top-p and text models like `text-davinci-003`. Streaming and logit_bias parameters are not supported

## Contributing

I'd welcome and appreciate contributions to aitemplates. If you'd like to contribute a feature, please submit a pull request. For bugs, please open a new issue, and I'll address it promptly.

==> aitemplates-0.1.4.tar.gz: aitemplates-0.1.4/README.md <==
# aitemplates

aitemplates is a Python package designed to simplify and streamline your work with the OpenAI API. It provides Python typing support, error checking, and a usage meter to help manage API costs. Additionally, aitemplates offers built-in examples of using ChromaDB and tools for efficient prompt engineering with OpenAI.

## Features

- **Python Typing Support**: Enjoy the benefits of Python's dynamic typing system while using OpenAI API.
- **Error Checking**: Automatically catch and handle errors during API calls.
- **Usage Meter**: Keep track of your OpenAI API usage with a built-in metering system.
- **ChromaDB Integration**: Work directly with ChromaDB from the aitemplates interface.
- **Asynchronous Chat Completions**: Use the `-asnc` flag to run asynchronous chat completions. The built-in `print_every` option prints every time a completion finishes in parallel. If a list is passed into the `response_list` attribute, it updates that list as completions finish. If you'd like to maintain the order of your completions, pass in the `keep_order` boolean as `True`.
- **Prompt Engineering Examples**: Get started quickly with included examples of prompt engineering techniques.

## Installation

You can install aitemplates directly from PyPI:

```bash
pip install aitemplates
```

To get the latest version of the package, you can also clone the repository and install the package by running `pip install -e .` in the repository directory.

## Creating Jupyter Notebook Templates

Create Jupyter notebook templates for prompt engineering with the following command:

```bash
aitemplates name_of_notebook
```

Include a Chroma database in the template with the `-db` flag:

```bash
aitemplates name_of_notebook -db
```

For asynchronous chat completions, add the `-asnc` flag:

```bash
aitemplates name_of_notebook -db -asnc
```

## Documentation

The package includes example notebooks, which provide comprehensive guides and demonstrations of the functionalities provided by aitemplates. To access these notebooks, access or clone the repository at [https://github.com/SilenNaihin/ai_templates](https://github.com/SilenNaihin/ai_templates) and navigate to the `/notebooks` directory.

Here are the available notebooks:

- `oai_examples.ipynb`: Provides examples for the OpenAI API.
- `chroma_examples.ipynb`: Demonstrates usage of ChromaDB.
- `prompt_engineering_example.ipynb`: A comprehensive guide on prompt engineering, including various techniques, usage of ChromaDB and the OpenAI library together.

## Requirements

- Be sure to have a `.env` file with the `OPENAI_API_KEY` defined in the root of your project or your api key defined in some way for OpenAI. AWS env variables are for ChromaDB deployment https://docs.trychroma.com/deployment
- This library doesn't currently support text models like `text-davinci-003`. Streaming and logit_bias parameters are also not supported

## Contributing

I welcome and appreciate contributions to aitemplates. If you'd like to contribute a feature, please submit a pull request. For bugs, please open a new issue, and I'll address it promptly.
